@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DecideHostConfig(AppConfig):
-    name = 'decide_host'
+    name = "decide_host"
